==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
var WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, _super);
    function WebFloatingPaneResizeMoveEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b = function (a) {
        if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        WebDockManagerPointDescriptionMetadata.d(a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c = function (a) {
        WebFloatingPaneResizeEventArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
        a.item("OldWidth", "Number:double");
        a.item("NewWidth", "Number:double");
        a.item("OldHeight", "Number:double");
        a.item("NewHeight", "Number:double");
        a.item("OldLocation", "ExportedType:WebDockManagerPoint");
        a.item("NewLocation", "ExportedType:WebDockManagerPoint");
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.d = function (a) {
        WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
        a.aa("WebFloatingPaneResizeMoveEventArgs", function () { return new WebFloatingPaneResizeMoveEventArgsDescription(); });
        a.z("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
}(Base));
export { WebFloatingPaneResizeMoveEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata } from "./WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
var WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, _super);
    function WebFloatingPaneResizeMoveEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b = function (a) {
        if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.d(a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebFloatingPaneResizeMoveEventArgsDetail");
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.d = function (a) {
        WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
        a.ac("WebFloatingPaneResizeMoveEventArgs", function () { return new WebFloatingPaneResizeMoveEventArgsDescription(); });
        a.ab("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
}(Base));
export { WebFloatingPaneResizeMoveEventArgsDescriptionMetadata };
